@@ -1,21 +1,24 @@
-import os
+import psutil
 from requests.auth import HTTPBasicAuth
+from typing import Optional
 
 from lockfilepy.exceptions import LolClientNotFound
 
 
 class Lockfile:
-    def __init__(self) -> None:
-        self.path = (
-            "C:\Riot Games\League of Legends"
-            if os.name == "nt"
-            else "/Applications/League of Legends.app/Contents/LoL"
-        )
-        try:
+    def __init__(self, path: Optional[str] = None) -> None:
+        if not path:
+            process = [
+                p
+                for p in psutil.process_iter(attrs=["pid", "name"])
+                if p.info["name"] == "LeagueClient.exe"
+            ]
+            if not process:
+                raise LolClientNotFound
+
+            self.path = process[0].cmdline()[0].rsplit("/", 1)[0]
             with open(self.path + "/lockfile", "r") as f:
                 self.data = f.readline().strip().split(":")
-        except:
-            raise LolClientNotFound
 
     @property
     def process(self) -> str:
